pub enum UpdateGlobalNetworkError {
AccessDenied(String),
Conflict(String),
InternalServer(String),
ResourceNotFound(String),
Throttling(String),
}Expand description
Errors returned by UpdateGlobalNetwork
Variants
AccessDenied(String)
You do not have sufficient access to perform this action.
Conflict(String)
There was a conflict processing the request. Updating or deleting the resource can cause an inconsistent state.
InternalServer(String)
The request has failed due to an internal error.
ResourceNotFound(String)
The specified resource could not be found.
Throttling(String)
The request was denied due to request throttling.
Implementations
Sourceimpl UpdateGlobalNetworkError
impl UpdateGlobalNetworkError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<UpdateGlobalNetworkError>